==> kdepim-3.2.3.tar.bz2: kdepim-3.2.3/kaddressbook/kablock.h <==
/*
    This file is part of KAddressBook.
    Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#ifndef KABLOCK_H
#define KABLOCK_H

#include <kabc/addressbook.h>
#include <kabc/resource.h>

typedef struct {
  KABC::Ticket *ticket;
  uint counter;
} LockEntry;

class KABLock
{
  public:
    ~KABLock();

    static KABLock *self( KABC::AddressBook *ab );

    bool lock( KABC::Resource* );
    bool unlock( KABC::Resource* );

  protected:
    KABLock( KABC::AddressBook *ab );

  private:
    static KABLock *mSelf;

    QMap<KABC::Resource*, LockEntry> mLocks;
    KABC::AddressBook *mAddressBook;
};

#endif

==> kdepim-3.4.2.tar.bz2: kdepim-3.4.2/kaddressbook/kablock.h <==
/*
    This file is part of KAddressBook.
    Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#ifndef KABLOCK_H
#define KABLOCK_H

namespace KABC {
class AddressBook;
class Resource;
class Ticket;
}

typedef struct {
  KABC::Ticket *ticket;
  uint counter;
} LockEntry;

class KABLock
{
  public:
    ~KABLock();

    static KABLock *self( KABC::AddressBook *ab );

    bool lock( KABC::Resource* );
    bool unlock( KABC::Resource* );

  protected:
    KABLock( KABC::AddressBook *ab );

  private:
    static KABLock *mSelf;

    QMap<KABC::Resource*, LockEntry> mLocks;
    KABC::AddressBook *mAddressBook;
};

#endif
